==> smart-wx-api-1.0.3-sources.jar: net/guerlab/smart/wx/api/autoconfig/WxUserLoginLogApiLocalServiceAutoConfigure.java <==
package net.guerlab.smart.wx.api.autoconfig;

import lombok.AllArgsConstructor;
import net.guerlab.smart.platform.commons.util.BeanConvertUtils;
import net.guerlab.smart.wx.api.WxUserLoginLogApi;
import net.guerlab.smart.wx.core.domain.WxUserLoginLogDTO;
import net.guerlab.smart.wx.core.searchparams.WxUserLoginLogSearchParams;
import net.guerlab.smart.wx.service.service.WxUserLoginLogService;
import net.guerlab.web.result.ListObject;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.context.annotation.*;
import org.springframework.core.type.AnnotatedTypeMetadata;
import org.springframework.lang.NonNull;

import java.util.List;

/**
 * @author guer
 */
@Configuration
@Conditional(WxUserLoginLogApiLocalServiceAutoConfigure.WrapperCondition.class)
public class WxUserLoginLogApiLocalServiceAutoConfigure {

    @SuppressWarnings("SpringJavaInjectionPointsAutowiringInspection")
    @Bean
    @ConditionalOnBean(WxUserLoginLogService.class)
    public WxUserLoginLogApi wxUserLoginLogApiLocalServiceWrapper(WxUserLoginLogService service) {
        return new WxUserLoginLogApiLocalServiceWrapper(service);
    }

    @SuppressWarnings("WeakerAccess")
    static class WrapperCondition implements Condition {

        @Override
        public boolean matches(@NonNull ConditionContext context, @NonNull AnnotatedTypeMetadata metadata) {
            try {
                return WrapperCondition.class.getClassLoader()
                        .loadClass("net.guerlab.smart.wx.service.service.WxUserLoginLogService") != null;
            } catch (Exception e) {
                return false;
            }
        }
    }

    @AllArgsConstructor
    private static class WxUserLoginLogApiLocalServiceWrapper implements WxUserLoginLogApi {

        private WxUserLoginLogService service;

        @Override
        public ListObject<WxUserLoginLogDTO> findList(WxUserLoginLogSearchParams searchParams) {
            return BeanConvertUtils.toListObject(service.selectPage(searchParams));
        }

        @Override
        public List<WxUserLoginLogDTO> findAll(WxUserLoginLogSearchParams searchParams) {
            return BeanConvertUtils.toList(service.selectAll(searchParams));
        }
    }

}

==> smart-wx-api-20.2.0-sources.jar: net/guerlab/smart/wx/api/autoconfig/WxUserLoginLogApiLocalServiceAutoConfigure.java <==
package net.guerlab.smart.wx.api.autoconfig;

import lombok.AllArgsConstructor;
import net.guerlab.smart.platform.commons.util.BeanConvertUtils;
import net.guerlab.smart.wx.api.WxUserLoginLogApi;
import net.guerlab.smart.wx.core.domain.WxUserLoginLogDTO;
import net.guerlab.smart.wx.core.searchparams.WxUserLoginLogSearchParams;
import net.guerlab.smart.wx.service.service.WxUserLoginLogService;
import net.guerlab.web.result.ListObject;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.context.annotation.*;
import org.springframework.core.type.AnnotatedTypeMetadata;
import org.springframework.lang.NonNull;

import java.util.List;

/**
 * @author guer
 */
@Configuration
@Conditional(WxUserLoginLogApiLocalServiceAutoConfigure.WrapperCondition.class)
public class WxUserLoginLogApiLocalServiceAutoConfigure {

    @SuppressWarnings("SpringJavaInjectionPointsAutowiringInspection")
    @Bean
    @ConditionalOnBean(WxUserLoginLogService.class)
    public WxUserLoginLogApi wxUserLoginLogApiLocalServiceWrapper(WxUserLoginLogService service) {
        return new WxUserLoginLogApiLocalServiceWrapper(service);
    }

    @SuppressWarnings("WeakerAccess")
    static class WrapperCondition implements Condition {

        @Override
        public boolean matches(@NonNull ConditionContext context, @NonNull AnnotatedTypeMetadata metadata) {
            try {
                return WrapperCondition.class.getClassLoader()
                        .loadClass("net.guerlab.smart.wx.service.service.WxUserLoginLogService") != null;
            } catch (Exception e) {
                return false;
            }
        }
    }

    @AllArgsConstructor
    private static class WxUserLoginLogApiLocalServiceWrapper implements WxUserLoginLogApi {

        private final WxUserLoginLogService service;

        @Override
        public ListObject<WxUserLoginLogDTO> findList(WxUserLoginLogSearchParams searchParams) {
            return BeanConvertUtils.toListObject(service.selectPage(searchParams));
        }

        @Override
        public List<WxUserLoginLogDTO> findAll(WxUserLoginLogSearchParams searchParams) {
            return BeanConvertUtils.toList(service.selectAll(searchParams));
        }
    }

}
